@@ -23,9 +23,7 @@
 #include <QIcon>
 #include <QReadWriteLock>
 #include <QSharedData>
-#include <QStringList>
 #include <QVariant>
-#include <QWeakPointer>
 
 #include "krunner_debug.h"
 
@@ -329,23 +327,25 @@ bool QueryMatch::operator!=(const QueryMatch &other) const
 
 void QueryMatch::run(const RunnerContext &context) const
 {
-    //qCDebug(KRUNNER) << "we run the term" << context->query() << "whose type is" << context->mimetype();
+    //qCDebug(KRUNNER) << "we run the term" << context.query() << "whose type is" << d->mimeType;
     if (d->runner) {
         d->runner.data()->run(context, *this);
     }
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 71)
 bool QueryMatch::hasConfigurationInterface() const
 {
-    return d->runner && d->runner.data()->hasRunOptions();
+    return false;
 }
+#endif
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 71)
 void QueryMatch::createConfigurationInterface(QWidget *parent)
 {
-    if (hasConfigurationInterface()) {
-        d->runner.data()->createRunOptions(parent);
-    }
+    Q_UNUSED(parent)
 }
+#endif
 
 } // Plasma namespace
 
